Crate deno_cache_dir

Crate deno_cache_dir 

Modules

file_fetcher
memory
npm

Structs

CacheEntry
Checksum
ChecksumIntegrityError
GlobalHttpCache
HttpCacheItemKey
Computed cache key, which can help reduce the work of computing the cache key multiple times.
LocalHttpCache
LocalLspHttpCache
A vendor/ folder http cache for the lsp that provides functionality for doing a reverse mapping.
ResolveDenoDirOptions
SerializedCachedUrlMetadata

Enums

CacheReadFileError
DenoDirResolutionError
GlobalOrLocalHttpCache
GlobalToLocalCopy

Constants

CACHE_PERM
Permissions used to save a file in the disk caches.
NOT_FOUND_CACHE_HEADER
Synthetic header stored on cache entries that record a 404 response from the remote server. This allows treating “not found” as cached information instead of re-requesting the URL on every process start. Similar to how redirects are stored as body-less entries distinguished by their “location” header.

Traits

GlobalHttpCacheSys
HttpCache
LocalHttpCacheSys
ResolveDenoDirSys

Functions

resolve_deno_dir
url_to_filename
Turn provided url into a hashed filename. URLs can contain a lot of characters that cannot be used in filenames (like “?”, “#”, “:”), so in order to cache them properly they are deterministically hashed into ASCII strings.

Type Aliases

GlobalHttpCacheRc
HeadersMap
HttpCacheRc
LocalHttpCacheRc